==> pegasus-merchandise-api-1.4.21-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsCustomizeImagePositionVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 定制区域
 */
public class PcsCustomizeImagePositionVO implements Serializable {

  private static final long serialVersionUID = 9142985194029654914L;


  //区域描述
  private String positionName;
  private BigDecimal positionX;
  private BigDecimal positionY;
  private BigDecimal length;
  private BigDecimal height;
  private BigDecimal fontSize;
  private Integer opacity = 100;

  public Integer getOpacity() {
    return opacity;
  }

  public void setOpacity(Integer opacity) {
    this.opacity = opacity;
  }

  public BigDecimal getPositionX() {
    return positionX;
  }

  public void setPositionX(BigDecimal positionX) {
    this.positionX = positionX;
  }

  public BigDecimal getPositionY() {
    return positionY;
  }

  public void setPositionY(BigDecimal positionY) {
    this.positionY = positionY;
  }

  public BigDecimal getLength() {
    return length;
  }

  public void setLength(BigDecimal length) {
    this.length = length;
  }

  public BigDecimal getHeight() {
    return height;
  }

  public void setHeight(BigDecimal height) {
    this.height = height;
  }

  public BigDecimal getFontSize() {
    return fontSize;
  }

  public void setFontSize(BigDecimal fontSize) {
    this.fontSize = fontSize;
  }

  public String getPositionName() {
    return positionName;
  }

  public void setPositionName(String positionName) {
    this.positionName = positionName;
  }
}

==> pegasus-merchandise-api-4.0.20-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsCustomizeImagePositionVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 定制区域
 */
public class PcsCustomizeImagePositionVO implements Serializable {

  private static final long serialVersionUID = 9142985194029654914L;


  //区域描述
  private String positionName;
  private Short positionType = 1; //定制类型
  private BigDecimal positionX;
  private BigDecimal positionY;
  private BigDecimal length;
  private BigDecimal height;
  private BigDecimal fontSize;
  private Integer opacity = 100;
  private Short borderDisplayRrule  = 1; //边框显示规则 （1显示，0 隐藏）
  private Short placementPosition = 2; //摆放位置 （1:居左， 2居中， 3居右）

  private Short contentType; //区域定制内容类型(1 ：订单日期)


  public Integer getOpacity() {
    return opacity;
  }

  public void setOpacity(Integer opacity) {
    this.opacity = opacity;
  }

  public BigDecimal getPositionX() {
    return positionX;
  }

  public void setPositionX(BigDecimal positionX) {
    this.positionX = positionX;
  }

  public BigDecimal getPositionY() {
    return positionY;
  }

  public void setPositionY(BigDecimal positionY) {
    this.positionY = positionY;
  }

  public BigDecimal getLength() {
    return length;
  }

  public void setLength(BigDecimal length) {
    this.length = length;
  }

  public BigDecimal getHeight() {
    return height;
  }

  public void setHeight(BigDecimal height) {
    this.height = height;
  }

  public BigDecimal getFontSize() {
    return fontSize;
  }

  public void setFontSize(BigDecimal fontSize) {
    this.fontSize = fontSize;
  }

  public String getPositionName() {
    return positionName;
  }

  public void setPositionName(String positionName) {
    this.positionName = positionName;
  }

  public Short getPositionType() {
    return positionType;
  }

  public void setPositionType(Short positionType) {
    this.positionType = positionType;
  }

  public Short getBorderDisplayRrule() {
    return borderDisplayRrule;
  }

  public void setBorderDisplayRrule(Short borderDisplayRrule) {
    this.borderDisplayRrule = borderDisplayRrule;
  }

  public Short getPlacementPosition() {
    return placementPosition;
  }

  public void setPlacementPosition(Short placementPosition) {
    this.placementPosition = placementPosition;
  }

  public Short getContentType() {
    return contentType;
  }

  public void setContentType(Short contentType) {
    this.contentType = contentType;
  }
}
